@@ -21,7 +21,9 @@
 int main(int argc, char *argv[])
 {
   // Fixes blurry icons with fractional scaling
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
   QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+#endif
   QApplication app(argc, argv);
 
   KLocalizedString::setApplicationDomain("ktuberling");
